@@ -1,4 +1,5 @@
 from os import path
+import inspect
 
 
 APPLY_TO_ALL = "**all**"
@@ -6,7 +7,7 @@ APPLY_TO_ALL = "**all**"
 # Global list of all mutants
 g_mutant_registry = {APPLY_TO_ALL:{}}
 
-# Current mutant (set by Mutant::apply_and_run)
+# Current mutant
 g_current_mutant = None
 
 linked_files = {}
@@ -20,18 +21,6 @@ class Mutant(object):
     def add_mapping(self, fname, fimpl):
         self.function_mappings[fname] = fimpl
 
-    def apply_and_run(self, f):
-        global g_current_mutant
-        g_current_mutant = self
-        result = True
-        try:
-            f()
-        except Exception:
-            result = False
-        g_current_mutant = None
-
-        return result
-
 
 def active_mutant(mutation):
     global g_current_mutant
@@ -51,21 +40,28 @@ def mut(mutation, good, bad):
     else:
         return good()
 
+def check_linked_files(file, default_value):
+    file = file if not file is None else default_value
+    files = []
+    if isinstance(file, str):
+        files = [linked_files[file]] if file in linked_files else [file]
+    elif isinstance(file, list):
+        for f in file:
+            files.append(linked_files[f] if f in linked_files else f)
+    else:
+        raise ValueError("file must be a string or a list of strings")
+    return files
+
 
 def mutant_of(fname, mutant_name, file=None, description=""):
 
     def decorator(f):
-        global linked_files
-        basename = file if not file is None else path.basename(f.__globals__['__file__'])
-        if isinstance(basename, str) and basename in linked_files:
-            basename = linked_files[basename]
-        has_mutant(mutant_name, basename, "")(f)
+        files = check_linked_files(file, path.basename(inspect.stack()[1].filename))
 
-        if isinstance(basename, str):
-            g_mutant_registry[basename][mutant_name].add_mapping(fname, f)
-        else:
-            for b in basename:
-                g_mutant_registry[b][mutant_name].add_mapping(fname, f)
+        has_mutant(mutant_name, files, "")(f)
+
+        for filename in files:
+            g_mutant_registry[filename][mutant_name].add_mapping(fname, f)
 
         return f
 
@@ -74,14 +70,7 @@ def mutant_of(fname, mutant_name, file=None, description=""):
 def has_mutant(mutant_name, file=None, description=""):
 
     def decorator(f):
-        if file is None:
-            files = [APPLY_TO_ALL]
-        elif isinstance(file, str):
-            files = [file]
-        elif isinstance(file, list):
-            files = file
-        else:
-            raise ValueError("file must be a string or a list of strings")
+        files = check_linked_files(file, APPLY_TO_ALL)
 
         for basename in files:
             if basename not in g_mutant_registry:
@@ -96,6 +85,31 @@ def has_mutant(mutant_name, file=None, description=""):
 def link_to_file(filename):
     global linked_files
 
-    import inspect
     current_file = path.basename(inspect.stack()[1].filename)
-    linked_files[current_file] = filename
\ No newline at end of file
+    linked_files[current_file] = filename
+
+def empty_function(*args, **kwargs):
+    pass
+
+def trivial_mutations(*args, **kwargs):
+    filename = kwargs.get("file", None)
+    object_to_mutate = kwargs.get("object", None)
+    if not object_to_mutate is None:
+        empty_function.__globals__[object_to_mutate.__name__] = object_to_mutate
+    if filename is None:
+        filename = path.basename(inspect.stack()[1].filename)
+
+    for fname in args:
+        mutant_of(fname, (fname.split('.')[-1]).upper() + "_NOTHING", file=filename)(empty_function)
+
+def reset_globals():
+    global g_mutant_registry
+    global linked_files
+    global g_current_mutant
+
+    linked_files.clear()
+    for file, mutants in g_mutant_registry.items():
+        for name, mutant in mutants.items():
+            del mutant
+    g_mutant_registry = {APPLY_TO_ALL:{}}
+    g_current_mutant = None
\ No newline at end of file
